@@ -5,42 +5,35 @@ build_time_vars = {'ABIFLAGS': 'm',
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': '@echo "Cannot generate $@, python not found !" && \\ '
-            '/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Parser/asdl_c.py',
- 'ASDLGEN_FILES': '/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Parser/asdl.py '
-                  '/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Parser/asdl_c.py',
- 'AST_ASDL': '/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Parser/Python.asdl',
- 'AST_C': 'Python/Python-ast.c',
- 'AST_C_DIR': 'Python',
- 'AST_H': 'Include/Python-ast.h',
- 'AST_H_DIR': 'Include',
- 'BASECFLAGS': '-fno-strict-aliasing -Wsign-compare',
- 'BASECPPFLAGS': '-IObjects -IInclude -IPython',
+ 'BASECFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code',
+ 'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/local/bin',
  'BINLIBDEST': '/usr/local/lib/python3.6',
  'BLDLIBRARY': '-L. -lpython3.6m',
  'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
-              '-L/usr/ports/pobj/Python-3.6.0/Python-3.6.0',
+              '-L/usr/obj/ports/Python-3.6.2/Python-3.6.2',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'mips64el-unknown-openbsd6.1',
+ 'BUILD_GNU_TYPE': 'x86_64-unknown-openbsd6.2',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -Wsign-compare -DNDEBUG -O2 -pipe   -fPIC -O2 '
-           '-pipe -O2 -pipe',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG -O2 '
+           '-pipe   -fPIC -O2 -pipe -O2 -pipe',
  'CFLAGSFORSHARED': '-fPIC',
+ 'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-O2 -pipe',
- 'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-parameter '
+ 'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
+                            '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers',
  'CONFIGURE_CPPFLAGS': '-I/usr/local/include',
  'CONFIGURE_LDFLAGS': '-L/usr/local/lib/',
  'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' "
-                "'--srcdir=/usr/ports/pobj/Python-3.6.0/Python-3.6.0' "
+                "'--srcdir=/usr/obj/ports/Python-3.6.2/Python-3.6.2' "
                 "'--with-fpectl' '--with-threads' '--enable-ipv6' "
                 "'--with-system-expat' '--with-system-ffi' "
                 "'--prefix=/usr/local' '--sysconfdir=/etc' "
@@ -51,13 +44,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.6m',
  'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/home/pea/pobj/Python-3.6.0/Python-3.6.0/coverage.info',
- 'COVERAGE_REPORT': '/home/pea/pobj/Python-3.6.0/Python-3.6.0/lcov-report',
+ 'COVERAGE_INFO': '/usr/obj/ports/Python-3.6.2/Python-3.6.2/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.6.2/Python-3.6.2/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
- 'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Include '
-             '-I/usr/local/include',
+ 'CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'CXX': 'c++ -pthread',
  'DESTDIRS': '/usr/local /usr/local/lib /usr/local/lib/python3.6 '
              '/usr/local/lib/python3.6/lib-dynload',
@@ -93,15 +84,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
  'GETTIMEOFDAY_NO_TZ': 0,
+ 'GITBRANCH': '',
+ 'GITTAG': '',
+ 'GITVERSION': '',
  'GNULD': 'yes',
- 'GRAMMAR_C': 'Python/graminit.c',
- 'GRAMMAR_H': 'Include/graminit.h',
- 'GRAMMAR_INPUT': '/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Grammar/Grammar',
  'HAVE_ACCEPT4': 1,
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
- 'HAVE_ALIGNED_REQUIRED': 1,
+ 'HAVE_ALIGNED_REQUIRED': 0,
  'HAVE_ALLOCA_H': 0,
  'HAVE_ALTZONE': 0,
  'HAVE_ASINH': 1,
@@ -118,7 +109,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_BROKEN_PTHREAD_SIGMASK': 0,
  'HAVE_BROKEN_SEM_GETVALUE': 0,
  'HAVE_BROKEN_UNSETENV': 0,
- 'HAVE_BUILTIN_ATOMIC': 0,
+ 'HAVE_BUILTIN_ATOMIC': 1,
  'HAVE_CHFLAGS': 1,
  'HAVE_CHOWN': 1,
  'HAVE_CHROOT': 1,
@@ -197,8 +188,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GAMMA': 1,
  'HAVE_GCC_ASM_FOR_MC68881': 0,
- 'HAVE_GCC_ASM_FOR_X64': 0,
- 'HAVE_GCC_ASM_FOR_X87': 0,
+ 'HAVE_GCC_ASM_FOR_X64': 1,
+ 'HAVE_GCC_ASM_FOR_X87': 1,
  'HAVE_GCC_UINT128_T': 1,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
@@ -421,6 +412,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
  'HAVE_SYS_POLL_H': 1,
+ 'HAVE_SYS_RANDOM_H': 0,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
  'HAVE_SYS_SENDFILE_H': 0,
@@ -475,30 +467,27 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HGBRANCH': '',
- 'HGTAG': '',
- 'HGVERSION': '',
- 'HOST_GNU_TYPE': 'mips64el-unknown-openbsd6.1',
+ 'HOST_GNU_TYPE': 'x86_64-unknown-openbsd6.2',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
                    '/usr/local/include/python3.6m '
                    '/usr/local/include/python3.6m',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python3.6m',
- 'INSTALL': '/usr/ports/pobj/Python-3.6.0/bin/install -c',
- 'INSTALL_DATA': '/usr/ports/pobj/Python-3.6.0/bin/install -c  -m 644',
- 'INSTALL_PROGRAM': '/usr/ports/pobj/Python-3.6.0/bin/install -c -s  -m 755',
- 'INSTALL_SCRIPT': '/usr/ports/pobj/Python-3.6.0/bin/install -c  -m 755',
- 'INSTALL_SHARED': '/usr/ports/pobj/Python-3.6.0/bin/install -c -m 555',
+ 'INSTALL': '/usr/obj/ports/Python-3.6.2/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-3.6.2/bin/install -c  -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.6.2/bin/install -c -s  -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.6.2/bin/install -c  -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-3.6.2/bin/install -c -m 555',
  'INSTSONAME': 'libpython3.6m.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
- 'LDFLAGS': '-L/usr/local/lib/ -L/usr/ports/pobj/Python-3.6.0/Python-3.6.0',
+ 'LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.6.2/Python-3.6.2',
  'LDLAST': '',
  'LDLIBRARY': 'libpython3.6m.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
-             '-L/usr/ports/pobj/Python-3.6.0/Python-3.6.0',
+             '-L/usr/obj/ports/Python-3.6.2/Python-3.6.2',
  'LDVERSION': '3.6m',
  'LIBC': '',
  'LIBDEST': '/usr/local/lib/python3.6',
@@ -531,7 +520,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MAINCC': 'cc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Modules/makesetup',
+ 'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/local/man',
  'MKDIR_P': 'mkdir -p',
  'MODLIBS': '',
@@ -557,16 +546,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPCODETARGETGEN': '\\',
- 'OPCODETARGETGEN_FILES': '\\',
- 'OPCODETARGETS_H': '\\',
- 'OPCODE_H': '/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Include/opcode.h',
- 'OPCODE_H_DIR': '/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Include',
- 'OPCODE_H_GEN': '@echo "Cannot generate $@, python not found !" && \\ '
-                 '/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Tools/scripts/generate_opcode_h.py '
-                 '/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Lib/opcode.py '
-                 '/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Include/opcode.h',
- 'OPCODE_H_SCRIPT': '/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Tools/scripts/generate_opcode_h.py',
  'OPT': '-DNDEBUG -O2 -pipe   -fPIC',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -597,24 +576,21 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': ':',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_GEN': '@echo "Cannot generate $@, python not found !" && \\',
+ 'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -Wsign-compare -DNDEBUG -O2 -pipe   -fPIC '
-              '-O2 -pipe -O2 -pipe',
- 'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-parameter '
-                     '-Wno-missing-field-initializers',
- 'PY_CORE_CFLAGS': '-fno-strict-aliasing -Wsign-compare -DNDEBUG -O2 -pipe   '
-                   '-fPIC -O2 -pipe -O2 -pipe -std=c99 -Wextra '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
-                   '-IObjects -IInclude -IPython -I. '
-                   '-I/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Include '
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG '
+              '-O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
+ 'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
+                     '-Wno-unused-parameter -Wno-missing-field-initializers',
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
+                   '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -std=c99 '
+                   '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -I. -I./Include '
                    '-I/usr/local/include -fPIC -DPy_BUILD_CORE',
- 'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Include '
-                '-I/usr/local/include',
+ 'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/usr/local/lib/ -L/usr/ports/pobj/Python-3.6.0/Python-3.6.0',
+ 'PY_LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.6.2/Python-3.6.2',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -623,7 +599,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/home/pea/pobj/Python-3.6.0/Python-3.6.0',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.6.2/Python-3.6.2',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
@@ -651,7 +627,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-36m',
  'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
- 'SRC_GDB_HOOKS': '/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -664,12 +640,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/pea/pobj/Python-3.6.0/Python-3.6.0 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.6.2/Python-3.6.2 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/pea/pobj/Python-3.6.0/Python-3.6.0 '
-               './python '
-               '/usr/ports/pobj/Python-3.6.0/Python-3.6.0/Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.6.2/Python-3.6.2 '
+               './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'THREADOBJ': 'Python/thread.o',
  'TIMEMODULE_LIB': 0,
@@ -680,7 +655,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'USE_COMPUTED_GOTOS': 0,
  'USE_INLINE': 1,
  'VERSION': '3.6',
- 'VPATH': '/usr/ports/pobj/Python-3.6.0/Python-3.6.0',
  'WANT_SIGFPE_HANDLER': 1,
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
@@ -693,9 +667,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/pea/pobj/Python-3.6.0/Python-3.6.0',
- 'abs_srcdir': '/usr/ports/pobj/Python-3.6.0/Python-3.6.0',
+ 'abs_builddir': '/usr/obj/ports/Python-3.6.2/Python-3.6.2',
+ 'abs_srcdir': '/usr/obj/ports/Python-3.6.2/Python-3.6.2',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
- 'srcdir': '/usr/ports/pobj/Python-3.6.0/Python-3.6.0'}
+ 'srcdir': '.'}
